.. complexity documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Contents:
=========

.. toctree::
   :maxdepth: 2
   usage
   contributing
   authors
   history

Feedback
========

If you encounter any errors or problems with **wagtailosm**, please let me know!
Open an Issue at the GitHub http://github.com/benjaoming/wagtailosm main repository.
